package com.hw.dms.mapper;

import java.util.List;
import com.hw.dms.domain.DmsKnowledgeMaint;

/**
 * 保养知识库Mapper接口
 * 
 * @author Open Platform
 * @date 2024-02-26
 */
public interface DmsKnowledgeMaintMapper 
{
    /**
     * 查询保养知识库
     * 
     * @param knowledgeMaintId 保养知识库主键
     * @return 保养知识库
     */
    public DmsKnowledgeMaint selectDmsKnowledgeMaintByKnowledgeMaintId(Long knowledgeMaintId);

    /**
     * 查询保养知识库列表
     * 
     * @param dmsKnowledgeMaint 保养知识库
     * @return 保养知识库集合
     */
    public List<DmsKnowledgeMaint> selectDmsKnowledgeMaintList(DmsKnowledgeMaint dmsKnowledgeMaint);

    /**
     * 新增保养知识库
     * 
     * @param dmsKnowledgeMaint 保养知识库
     * @return 结果
     */
    public int insertDmsKnowledgeMaint(DmsKnowledgeMaint dmsKnowledgeMaint);

    /**
     * 修改保养知识库
     * 
     * @param dmsKnowledgeMaint 保养知识库
     * @return 结果
     */
    public int updateDmsKnowledgeMaint(DmsKnowledgeMaint dmsKnowledgeMaint);

    /**
     * 删除保养知识库
     * 
     * @param knowledgeMaintId 保养知识库主键
     * @return 结果
     */
    public int deleteDmsKnowledgeMaintByKnowledgeMaintId(Long knowledgeMaintId);

    /**
     * 批量删除保养知识库
     * 
     * @param knowledgeMaintIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDmsKnowledgeMaintByKnowledgeMaintIds(Long[] knowledgeMaintIds);
}
